#ifndef NT2_INCLUDE_FUNCTIONS_MAJORITY_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_MAJORITY_HPP_INCLUDED

#include <nt2/predicates/include/functions/majority.hpp>

#endif
